@@ -1,17 +1,18 @@
 ## Copyright (C) 2005 Julius O. Smith III <jos@ccrma.stanford.edu>
 ##
-## This program is free software; you can redistribute it and/or modify it under
-## the terms of the GNU General Public License as published by the Free Software
-## Foundation; either version 3 of the License, or (at your option) any later
-## version.
+## This program is free software: you can redistribute it and/or modify
+## it under the terms of the GNU General Public License as published by
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
-## This program is distributed in the hope that it will be useful, but WITHOUT
-## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
-## details.
+## This program is distributed in the hope that it will be useful,
+## but WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+## GNU General Public License for more details.
 ##
-## You should have received a copy of the GNU General Public License along with
-## this program; if not, see <http://www.gnu.org/licenses/>.
+## You should have received a copy of the GNU General Public License
+## along with this program; see the file COPYING. If not, see
+## <https://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn  {Function File} {[@var{z}, @var{p}, @var{k}] =} sos2zp (@var{sos})
@@ -52,9 +53,17 @@
 ## EXAMPLE:
 ## @example
 ## [z, p, k] = sos2zp ([1 0 1, 1 0 -0.81; 1 0 0, 1 0 0.49])
-##     @result{} z = [i; -i; 0; 0]
-##     @result{} p = [0.9, -0.9, 0.7i, -0.7i]
-##     @result{} k = 1
+##   @result{} z =
+##     -0 + 1i
+##      0 - 1i
+##      0 + 0i
+##      0 + 0i
+##   @result{} p =
+##     -0.90000 + 0.00000i
+##      0.90000 + 0.00000i
+##     -0.00000 + 0.70000i
+##      0.00000 - 0.70000i
+##   @result{} k =  1
 ## @end example
 ##
 ## @seealso{zp2sos, sos2tf, tf2sos, zp2tf, tf2zp}
