@@ -1,27 +1,32 @@
-// Copyright (C) 2008 Eric Chassande-Mottin, CNRS (France) <ecm@apc.univ-paris7.fr>
-//
-// This program is free software; you can redistribute it and/or modify it under
-// the terms of the GNU General Public License as published by the Free Software
-// Foundation; either version 3 of the License, or (at your option) any later
-// version.
-//
-// This program is distributed in the hope that it will be useful, but WITHOUT
-// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
-// details.
-//
-// You should have received a copy of the GNU General Public License along with
-// this program; if not, see <http://www.gnu.org/licenses/>.
+/*
 
-#include <octave/config.h>
+Copyright (C) 2008 Eric Chassande-Mottin, CNRS (France) <ecm@apc.univ-paris7.fr>
+
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; see the file COPYING.  If not, see
+<https://www.gnu.org/licenses/>.
+
+*/
+
+#include <octave/oct.h>
 #include <octave/defun-dld.h>
 #include <octave/error.h>
-#include <octave/gripes.h>
-#include <octave/oct-obj.h>
 #include <octave/pager.h>
 #include <octave/quit.h>
 #include <octave/variables.h>
 
+#include "octave-compat.h"
+
 DEFUN_DLD (sosfilt, args, ,
   "-*- texinfo -*-\n\
 @deftypefn {Loadable Function} {@var{y} =} sosfilt (@var{sos}, @var{x})\n\
@@ -52,7 +57,7 @@ section 1, etc.  The b0 entry must be nonzero for each section.\n\
 
   if (error_state)
     {
-      gripe_wrong_type_arg("sosfilt",args(0));
+      err_wrong_type_arg ("sosfilt", args(0));
       return retval;
     }
 
@@ -66,7 +71,7 @@ section 1, etc.  The b0 entry must be nonzero for each section.\n\
 
   if (error_state)
     {
-      gripe_wrong_type_arg("sosfilt",args(1));
+      err_wrong_type_arg ("sosfilt", args(1));
       return retval;
     }
 
